pub fn bundled_registry() -> Result<FontRegistry, FontError>Expand description
A registry with the bundled family registered — both slopes, and every weight each file names — and all generics mapped to it.
pub fn bundled_registry() -> Result<FontRegistry, FontError>A registry with the bundled family registered — both slopes, and every weight each file names — and all generics mapped to it.