pub struct LineSpan {
pub runs: Range<usize>,
pub offset: f32,
pub width: u32,
}Expand description
One span of a line: the runs set in it, and where they go.
Fields
runs: Range<usize>The runs of Line::runs set here.
offset: f32Points from the line’s own leading edge the span is set at.
width: u32Advance of the span’s glyphs, in font units.