pub struct OutlineEntry {
pub title: String,
pub level: u8,
pub place: PageBox,
pub children: Vec<OutlineEntry>,
}Expand description
One heading in the outline.
Fields
title: StringThe heading’s words, markup discarded and a line break as a space.
level: u8The heading’s level, from 1 to 6.
place: PageBoxThe box of the heading, on the page it is set on.
children: Vec<OutlineEntry>The headings after this one and deeper than it, up to the next heading at its level or above.