pub struct PageBox {
pub page: u32,
pub x: f32,
pub y: f32,
pub width: f32,
pub height: f32,
}Expand description
One box on one page, in points, origin top-left.
Fields
page: u32Which page of the book the box is on, counting from 0.
x: f32Left edge.
y: f32Top edge.
width: f32Width in points.
height: f32Height in points.
Implementations