pub struct Radius {
pub x: f32,
pub y: f32,
}Expand description
How far one corner of a box is rounded: the two radii of the quarter ellipse the corner follows, in points.
Fields
x: f32Along the top or bottom edge.
y: f32Along the left or right edge.
Implementations