pub enum ColumnSpan {
None,
All,
}Expand description
How many columns of a divided page a block is set across, from
column-span.
Variants
None
none: the block is set in one column.
All
all: the block is set across the whole content box, with
columns above it and columns below it.