pub enum ContentPiece {
Text(String),
TargetCounter {
target: Target,
style: CounterStyle,
},
TargetText {
target: Target,
},
}Expand description
One piece of a content value that names another element.
Variants
Text(String)
A literal.
TargetCounter
target-counter(): the folio of the page the target lands on,
spelled as the style names.
Fields

style: CounterStyleHow the folio is spelled.
TargetText
target-text(): the text of the target itself.