pub enum LineHeight {
Normal,
Number(f32),
Length(Length),
}Expand description
line-height, before the font size it multiplies is known.
Variants
Normal
The font’s own idea of leading.
Number(f32)
A multiple of the font size.
Length(Length)
A length, which computes to the multiple it works out as.
Implementations
Sourceimpl LineHeight
impl LineHeight
Sourcepub fn to_multiple(self, size: f32, root: f32) -> f32
pub fn to_multiple(self, size: f32, root: f32) -> f32
The unitless multiple this computes to at size.