pub enum Width {
Auto,
Points(f32),
Percent(f32),
}Expand description
The size a box is asked to take on one axis, from width,
height or min-height.
Variants
Auto
auto: the box takes the size that layout gives it.
Points(f32)
A length, in points.
Percent(f32)
A percentage of the same axis of the box around it.
Implementations