pub fn text(inlines: &[Inline]) -> String
The text of an inline tree, markup discarded: every inline run together and a hard break as a newline, as content() reads an element and as a frontend reads alt text.
content()